@@ -28,6 +28,15 @@ _type_articles = {
     "ACL role": "an",
     "ACL permission": "an",
 }
+_file_role_translation = {
+    "BOOTH_CONFIG": "Booth configuration",
+    "BOOTH_KEY": "Booth key",
+    "COROSYNC_AUTHKEY": "Corosync authkey",
+    "PACEMAKER_AUTHKEY": "Pacemaker authkey",
+    "PCSD_SSL_CERT": "pcsd SSL certificate",
+    "PCSD_SSL_KEY": "pcsd SSL key",
+    "PCS_SETTINGS_CONF": "pcs configuration",
+}
 
 def warn(message):
     sys.stdout.write(format_message(message, "Warning: "))
@@ -58,6 +67,9 @@ def format_fencing_level_target(target_type, target_value):
         return "{0}={1}".format(target_value[0], target_value[1])
     return target_value
 
+def format_file_role(role):
+    return _file_role_translation.get(role, role)
+
 def service_operation_started(operation, info):
     return "{operation} {service}{instance_suffix}...".format(
         operation=operation,
@@ -1260,23 +1272,27 @@ CODE_TO_MESSAGE_BUILDER_MAP = {
     ,
 
     codes.FILE_ALREADY_EXISTS: lambda info:
-        "{node_prefix}{role_prefix}file {file_path} already exists"
+        "{_node}{_file_role} file '{file_path}' already exists"
         .format(
-            node_prefix=format_optional(info["node"], NODE_PREFIX),
-            role_prefix=format_optional(info["file_role"], "{0} "),
+            _node=format_optional(info["node"], NODE_PREFIX),
+            _file_role=format_file_role(info["file_role"]),
             **info
         )
     ,
 
     codes.FILE_DOES_NOT_EXIST: lambda info:
-        "{file_role} file {file_path} does not exist"
-        .format(**info)
+        "{_file_role} file '{file_path}' does not exist"
+        .format(
+            _file_role=format_file_role(info["file_role"]),
+            **info
+        )
     ,
 
     codes.FILE_IO_ERROR: lambda info:
-        "unable to {operation} {file_role}{path_desc}: {reason}"
+        "Unable to {operation} {_file_role}{_file_path}: {reason}"
         .format(
-            path_desc=format_optional(info["file_path"], " '{0}'"),
+            _file_path=format_optional(info["file_path"], " '{0}'"),
+            _file_role=format_file_role(info["file_role"]),
             **info
         )
     ,
@@ -1389,4 +1405,37 @@ CODE_TO_MESSAGE_BUILDER_MAP = {
     codes.UNABLE_TO_PERFORM_OPERATION_ON_ANY_NODE:
         "Unable to perform operation on any available node/host, therefore it "
         "is not possible to continue."
+    ,
+    codes.SBD_LIST_WATCHDOG_ERROR: lambda info:
+        "Unable to query available watchdogs from sbd: {reason}".format(**info)
+    ,
+    codes.SBD_WATCHDOG_NOT_SUPPORTED: lambda info:
+        (
+            "{node}: Watchdog '{watchdog}' is not supported (it may be a "
+            "software watchdog)"
+        ).format(**info)
+    ,
+    codes.SBD_WATCHDOG_VALIDATION_INACTIVE:
+        "Not validating the watchdog"
+    ,
+    codes.SBD_WATCHDOG_TEST_ERROR: lambda info:
+        "Unable to initialize test of the watchdog: {reason}".format(**info)
+    ,
+    codes.SBD_WATCHDOG_TEST_MULTUPLE_DEVICES:
+        "Multiple watchdog devices available, therefore, watchdog which should "
+        "be tested has to be specified. To list available watchdog devices use "
+        "command 'pcs stonith sbd watchdog list'"
+    ,
+    codes.SBD_WATCHDOG_TEST_FAILED:
+        "System should have been reset already"
+    ,
+    codes.SYSTEM_WILL_RESET:
+        "System will reset shortly"
+    ,
+    codes.RESOURCE_IN_BUNDLE_NOT_ACCESSIBLE: lambda info:
+        (
+            "Resource '{resource_id}' will not be accessible by the cluster "
+            "inside bundle '{bundle_id}'. At least one of bundle options "
+            "'control-port' or 'ip-range-start' has to be specified."
+        ).format(**info)
 }
