@@ -2081,3 +2081,146 @@ class CibPushForcedFullDueToCrmFeatureSet(NameBuildTest):
                 "current_set": "3.0.6",
             }
         )
+
+
+class SbdListWatchdogError(NameBuildTest):
+    code = codes.SBD_LIST_WATCHDOG_ERROR
+    def test_success(self):
+        self.assert_message_from_info(
+            "Unable to query available watchdogs from sbd: this is a reason",
+            {
+                "reason": "this is a reason",
+            }
+        )
+
+
+class SbdWatchdogNotSupported(NameBuildTest):
+    code = codes.SBD_WATCHDOG_NOT_SUPPORTED
+    def test_success(self):
+        self.assert_message_from_info(
+            (
+                "node1: Watchdog '/dev/watchdog' is not supported (it may be a "
+                "software watchdog)"
+            ),
+            {
+                "node": "node1",
+                "watchdog": "/dev/watchdog"
+            }
+        )
+
+
+class SbdWatchdogTestError(NameBuildTest):
+    code = codes.SBD_WATCHDOG_TEST_ERROR
+    def test_success(self):
+        self.assert_message_from_info(
+            "Unable to initialize test of the watchdog: some reason",
+            {
+                "reason": "some reason",
+            }
+        )
+
+
+class ResourceInBundleNotAccessible(NameBuildTest):
+    code = codes.RESOURCE_IN_BUNDLE_NOT_ACCESSIBLE
+    def test_success(self):
+        self.assert_message_from_info(
+            (
+                "Resource 'resourceA' will not be accessible by the cluster "
+                "inside bundle 'bundleA'. At least one of bundle options "
+                "'control-port' or 'ip-range-start' has to be specified."
+            ),
+            dict(
+                bundle_id="bundleA",
+                resource_id="resourceA",
+            )
+        )
+
+class FileAlreadyExists(NameBuildTest):
+    code = codes.FILE_ALREADY_EXISTS
+    def test_minimal(self):
+        self.assert_message_from_info(
+            "Corosync authkey file '/etc/corosync/key' already exists",
+            {
+                "file_role": "COROSYNC_AUTHKEY",
+                "file_path": "/etc/corosync/key",
+                "node": None,
+            }
+        )
+
+    def test_with_node(self):
+        self.assert_message_from_info(
+            "node1: pcs configuration file '/var/lib/pcsd/conf' already exists",
+            {
+                "file_role": "PCS_SETTINGS_CONF",
+                "file_path": "/var/lib/pcsd/conf",
+                "node": "node1",
+            }
+        )
+
+class FileDoesNotExist(NameBuildTest):
+    code = codes.FILE_DOES_NOT_EXIST
+    def test_success(self):
+        self.assert_message_from_info(
+            "UNKNOWN_ROLE file '/etc/cluster/something' does not exist",
+            {
+                "file_role": "UNKNOWN_ROLE",
+                "file_path": "/etc/cluster/something",
+            }
+        )
+
+class FileIoError(NameBuildTest):
+    code = codes.FILE_IO_ERROR
+    def test_success_a(self):
+        self.assert_message_from_info(
+            "Unable to chown Booth key '/etc/booth/booth.key': Failed",
+            {
+                "file_role": "BOOTH_KEY",
+                "file_path": "/etc/booth/booth.key",
+                "reason": "Failed",
+                "operation": "chown",
+            }
+        )
+
+    def test_success_b(self):
+        self.assert_message_from_info(
+            "Unable to chmod Booth configuration '/etc/booth/main.cfg': Failed",
+            {
+                "file_role": "BOOTH_CONFIG",
+                "file_path": "/etc/booth/main.cfg",
+                "reason": "Failed",
+                "operation": "chmod",
+            }
+        )
+
+    def test_success_c(self):
+        self.assert_message_from_info(
+            "Unable to remove Pacemaker authkey '/etc/pacemaker/key': Failed",
+            {
+                "file_role": "PACEMAKER_AUTHKEY",
+                "file_path": "/etc/pacemaker/key",
+                "reason": "Failed",
+                "operation": "remove",
+            }
+        )
+
+    def test_success_d(self):
+        self.assert_message_from_info(
+            "Unable to read pcsd SSL certificate '/var/lib/pcsd.crt': Failed",
+            {
+                "file_role": "PCSD_SSL_CERT",
+                "file_path": "/var/lib/pcsd.crt",
+                "reason": "Failed",
+                "operation": "read",
+            }
+        )
+
+    def test_success_e(self):
+        self.assert_message_from_info(
+            "Unable to write pcsd SSL key '/var/lib/pcsd.key': Failed",
+            {
+                "file_role": "PCSD_SSL_KEY",
+                "file_path": "/var/lib/pcsd.key",
+                "reason": "Failed",
+                "operation": "write",
+            }
+        )
