@@ -22,10 +22,12 @@ FORCE_QDEVICE_USED = "QDEVICE_USED"
 FORCE_STONITH_RESOURCE_DOES_NOT_EXIST = "FORCE_STONITH_RESOURCE_DOES_NOT_EXIST"
 FORCE_NOT_SUITABLE_COMMAND = "FORCE_NOT_SUITABLE_COMMAND"
 FORCE_CLEAR_CLUSTER_NODE = "FORCE_CLEAR_CLUSTER_NODE"
+FORCE_RESOURCE_IN_BUNDLE_NOT_ACCESSIBLE = "FORCE_RESOURCE_IN_BUNDLE_NOT_ACCESSIBLE"
 SKIP_OFFLINE_NODES = "SKIP_OFFLINE_NODES"
 SKIP_FILE_DISTRIBUTION_ERRORS = "SKIP_FILE_DISTRIBUTION_ERRORS"
 SKIP_ACTION_ON_NODES_ERRORS = "SKIP_ACTION_ON_NODES_ERRORS"
 SKIP_UNREADABLE_CONFIG = "SKIP_UNREADABLE_CONFIG"
+SKIP_WATCHDOG_VALIDATION = "SKIP_WATCHDOG_VALIDATION"
 
 AGENT_NAME_GUESS_FOUND_MORE_THAN_ONE = "AGENT_NAME_GUESS_FOUND_MORE_THAN_ONE"
 AGENT_NAME_GUESS_FOUND_NONE = "AGENT_NAME_GUESS_FOUND_NONE"
@@ -187,6 +189,7 @@ QDEVICE_USED_BY_CLUSTERS = "QDEVICE_USED_BY_CLUSTERS"
 REQUIRED_OPTION_IS_MISSING = "REQUIRED_OPTION_IS_MISSING"
 REQUIRED_OPTION_OF_ALTERNATIVES_IS_MISSING = "REQUIRED_OPTION_OF_ALTERNATIVES_IS_MISSING"
 RESOURCE_BUNDLE_ALREADY_CONTAINS_A_RESOURCE = "RESOURCE_BUNDLE_ALREADY_CONTAINS_A_RESOURCE"
+RESOURCE_IN_BUNDLE_NOT_ACCESSIBLE = "RESOURCE_IN_BUNDLE_NOT_ACCESSIBLE"
 RESOURCE_CANNOT_BE_NEXT_TO_ITSELF_IN_GROUP = "RESOURCE_CANNOT_BE_NEXT_TO_ITSELF_IN_GROUP"
 RESOURCE_CLEANUP_ERROR = "RESOURCE_CLEANUP_ERROR"
 RESOURCE_DOES_NOT_RUN = "RESOURCE_DOES_NOT_RUN"
@@ -218,11 +221,17 @@ SBD_DEVICE_MESSAGE_ERROR = "SBD_DEVICE_MESSAGE_ERROR"
 SBD_DEVICE_PATH_NOT_ABSOLUTE = "SBD_DEVICE_PATH_NOT_ABSOLUTE"
 SBD_DISABLING_STARTED = "SBD_DISABLING_STARTED"
 SBD_ENABLING_STARTED = "SBD_ENABLING_STARTED"
+SBD_LIST_WATCHDOG_ERROR = "SBD_LIST_WATCHDOG_ERROR"
 SBD_NO_DEVICE_FOR_NODE = "SBD_NO_DEVICE_FOR_NODE"
 SBD_NOT_ENABLED = "SBD_NOT_ENABLED"
 SBD_NOT_INSTALLED = "SBD_NOT_INSTALLED"
 SBD_REQUIRES_ATB = "SBD_REQUIRES_ATB"
 SBD_TOO_MANY_DEVICES_FOR_NODE = "SBD_TOO_MANY_DEVICES_FOR_NODE"
+SBD_WATCHDOG_NOT_SUPPORTED = "SBD_WATCHDOG_NOT_SUPPORTED"
+SBD_WATCHDOG_VALIDATION_INACTIVE = "SBD_WATCHDOG_VALIDATION_INACTIVE"
+SBD_WATCHDOG_TEST_ERROR = "SBD_WATCHDOG_TEST_ERROR"
+SBD_WATCHDOG_TEST_MULTUPLE_DEVICES = "SBD_WATCHDOG_TEST_MULTUPLE_DEVICES"
+SBD_WATCHDOG_TEST_FAILED = "SBD_WATCHDOG_TEST_FAILED"
 SERVICE_DISABLE_ERROR = "SERVICE_DISABLE_ERROR"
 SERVICE_DISABLE_STARTED = "SERVICE_DISABLE_STARTED"
 SERVICE_DISABLE_SUCCESS = "SERVICE_DISABLE_SUCCESS"
@@ -243,6 +252,7 @@ STONITH_RESOURCES_DO_NOT_EXIST = "STONITH_RESOURCES_DO_NOT_EXIST"
 SERVICE_COMMANDS_ON_NODES_STARTED = "SERVICE_COMMANDS_ON_NODES_STARTED"
 SERVICE_COMMAND_ON_NODE_ERROR = "SERVICE_COMMAND_ON_NODE_ERROR"
 SERVICE_COMMAND_ON_NODE_SUCCESS = "SERVICE_COMMAND_ON_NODE_SUCCESS"
+SYSTEM_WILL_RESET = "SYSTEM_WILL_RESET"
 TMP_FILE_WRITE = "TMP_FILE_WRITE"
 UNABLE_TO_DETERMINE_USER_UID = "UNABLE_TO_DETERMINE_USER_UID"
 UNABLE_TO_DETERMINE_GROUP_GID = "UNABLE_TO_DETERMINE_GROUP_GID"
