@@ -167,6 +167,10 @@ def capabilities(params, request, auth_user)
   })
 end
 
+def param_to_bool(obj)
+  return ['true', '1', 'on'].include?(obj)
+end
+
 # provides remote cluster status to a local gui
 def cluster_status_gui(auth_user, cluster_name, dont_update_config=false)
   cluster_nodes = get_cluster_nodes(cluster_name)
@@ -229,33 +233,16 @@ def cluster_status_remote(params, request, auth_user)
   return JSON.generate(status)
 end
 
-def cluster_start(params, request, auth_user)
-  if params[:name]
-    code, response = send_request_with_token(
-      auth_user, params[:name], 'cluster_start', true
-    )
-  else
-    if not allowed_for_local_cluster(auth_user, Permissions::WRITE)
-      return 403, 'Permission denied'
-    end
-    $logger.info "Starting Daemons"
-    output, stderr, retval = run_cmd(auth_user, PCS, 'cluster', 'start')
-    $logger.debug output
-    if retval != 0
-      return [400, (output + stderr).join]
-    else
-      return output
-    end
+def _cluster_start_stop(action, params, request, auth_user)
+  if not ['start', 'stop'].include?(action)
+    return [400, "Action can be 'start' or 'stop', got '#{action}'"]
   end
-end
-
-def cluster_stop(params, request, auth_user)
   if params[:name]
     params_without_name = params.reject {|key, value|
       key == "name" or key == :name
     }
     code, response = send_request_with_token(
-      auth_user, params[:name], 'cluster_stop', true, params_without_name
+      auth_user, params[:name], "cluster_#{action}", true, params_without_name
     )
   else
     if not allowed_for_local_cluster(auth_user, Permissions::WRITE)
@@ -269,19 +256,31 @@ def cluster_stop(params, request, auth_user)
         options << "--corosync"
       end
     end
-    options << "--force" if params["force"]
-    $logger.info "Stopping Daemons"
+    if action == "stop"
+      options << "--force" if params["force"]
+      $logger.info "Stopping Daemons"
+    else
+      $logger.info "Starting Daemons"
+    end
     stdout, stderr, retval = run_cmd(
-      auth_user, PCS, "cluster", "stop", *options
+      auth_user, PCS, 'cluster', action, *options
     )
     if retval != 0
-      return [400, stderr.join]
+      return [400, (stdout + stderr).join]
     else
       return stdout.join
     end
   end
 end
 
+def cluster_start(params, request, auth_user)
+  return _cluster_start_stop('start', params, request, auth_user)
+end
+
+def cluster_stop(params, request, auth_user)
+  return _cluster_start_stop('stop', params, request, auth_user)
+end
+
 def config_backup(params, request, auth_user)
   if params[:name]
     code, response = send_request_with_token(
@@ -646,8 +645,8 @@ def set_certs(params, request, auth_user)
       return [400, ssl_errors.join]
     end
     begin
-      write_file_lock(CRT_FILE, 0700, ssl_cert)
-      write_file_lock(KEY_FILE, 0700, ssl_key)
+      write_file_lock(CRT_FILE, 0600, ssl_cert)
+      write_file_lock(KEY_FILE, 0600, ssl_key)
     rescue => e
       # clean the files if we ended in the middle
       # the files will be regenerated on next pcsd start
@@ -843,7 +842,8 @@ def remote_add_node(params, request, auth_user, all=false)
       device_list = params[:devices]
     end
     retval, output = add_node(
-      auth_user, node, all, auto_start, params[:watchdog], device_list
+      auth_user, node, all, auto_start, params[:watchdog], device_list,
+      param_to_bool(params[:no_watchdog_validation]),
     )
   end
 
@@ -1650,7 +1650,7 @@ def remove_resource(params, request, auth_user)
         out, err, retval = run_cmd(user, *(cmd + [resource]))
         if retval != 0
           unless (
-            (out + err).join('').include?('unable to find a resource') and
+            (out + err).join('').include?(' does not exist') and
             no_error_if_not_exists
           )
             errors += "Unable to stop resource '#{resource}': #{err.join('')}"
@@ -2394,11 +2394,26 @@ def check_sbd(param, request, auth_user)
     }
   }
   watchdog = param[:watchdog]
-  if watchdog
-    out[:watchdog] = {
-      :path => watchdog,
-      :exist => File.exist?(watchdog)
-    }
+  if not watchdog.to_s.empty?
+    stdout, stderr, ret_val = run_cmd(
+      auth_user, PCS, 'stonith', 'sbd', 'watchdog', 'list_json'
+    )
+    if ret_val != 0
+      return [400, "Unable to get list of watchdogs: #{stderr.join("\n")}"]
+    end
+    begin
+      available_watchdogs = JSON.parse(stdout.join("\n"))
+      exists = available_watchdogs.include?(watchdog)
+      out[:watchdog] = {
+        :path => watchdog,
+        :exist => exists,
+        :is_supported => (
+          exists and available_watchdogs[watchdog]['caution'] == nil
+        ),
+      }
+    rescue JSON::ParserError
+      return [400, "Unable to get list of watchdogs: unable to parse JSON"]
+    end
   end
   begin
     device_list = JSON.parse(param[:device_list])
@@ -2521,10 +2536,14 @@ def remote_enable_sbd(params, request, auth_user)
 
   arg_list = []
 
-  if ['true', '1', 'on'].include?(params[:ignore_offline_nodes])
+  if param_to_bool(params[:ignore_offline_nodes])
     arg_list << '--skip-offline'
   end
 
+  if param_to_bool(params[:no_watchdog_validation])
+    arg_list << '--no-watchdog-validation'
+  end
+
   params[:watchdog].each do |node, watchdog|
     unless watchdog.strip.empty?
       arg_list << "--watchdog=#{watchdog.strip}@#{node}"
